@@ -216,7 +216,7 @@ void crashrecover()
       unlink(xobjs.tempfile);
       free(xobjs.tempfile);
    }
-   xobjs.tempfile = mystrdup(_STR2);
+   xobjs.tempfile = strdup(_STR2);
 
    startloadfile();
 }
@@ -445,7 +445,7 @@ void newfilelist(xcWidget w, popupstruct *okaystruct)
 #ifdef TCL_WRAPPER
    int bval;
    int result;
-   char *cstr = Tcl_GetVar2(xcinterp, "XCOps", "filter", TCL_NAMESPACE_ONLY);
+   char *cstr = (char *)Tcl_GetVar2(xcinterp, "XCOps", "filter", TCL_NAMESPACE_ONLY);
    if (cstr == NULL) {
       Wprintf("Error: No variable $XCOps(filter) in Tcl!");
       return;
